==> libreoffice_7.3.7.orig.tar.xz: libreoffice-7.3.7.2/vcl/inc/quartz/utils.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_VCL_INC_QUARTZ_UTILS_H
#define INCLUDED_VCL_INC_QUARTZ_UTILS_H

#include <iostream>

#include <premac.h>
#include <CoreFoundation/CoreFoundation.h>
#include <Foundation/Foundation.h>
#ifdef MACOSX
#include <ApplicationServices/ApplicationServices.h>
#else
#include <CoreGraphics/CoreGraphics.h>
#endif
#include <postmac.h>

#include <rtl/ustring.hxx>

OUString GetOUString( CFStringRef );
OUString GetOUString( const NSString* );
CFStringRef CreateCFString( const OUString& );
NSString* CreateNSString( const OUString& );
OUString NSStringArrayToOUString(NSArray* array);
OUString NSDictionaryKeysToOUString(NSDictionary* dict);

std::ostream &operator <<(std::ostream& s, const CGRect &rRect);
std::ostream &operator <<(std::ostream& s, const CGPoint &rPoint);
std::ostream &operator <<(std::ostream& s, const CGSize &rSize);
std::ostream &operator <<(std::ostream& s, CGColorRef pSize);
std::ostream &operator <<(std::ostream& s, const CGAffineTransform &aXform);
std::ostream &operator <<(std::ostream& s, CGColorSpaceRef cs);

#endif // INCLUDED_VCL_INC_QUARTZ_UTILS_H

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_26.2.0~rc3.orig.tar.xz: libreoffice-26.2.0.3/vcl/inc/quartz/utils.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#pragma once

#include <iostream>

#include <premac.h>
#include <CoreFoundation/CoreFoundation.h>
#include <Foundation/Foundation.h>
#ifdef MACOSX
#include <ApplicationServices/ApplicationServices.h>
#else
#include <CoreGraphics/CoreGraphics.h>
#endif
#include <postmac.h>

#include <rtl/ustring.hxx>

OUString GetOUString( CFStringRef );
OUString GetOUString( const NSString* );
CFStringRef CreateCFString( const OUString& );
NSString* CreateNSString( const OUString& );
OUString NSStringArrayToOUString(NSArray* array);
OUString NSDictionaryKeysToOUString(NSDictionary* dict);

std::ostream &operator <<(std::ostream& s, const CGRect &rRect);
std::ostream &operator <<(std::ostream& s, const CGPoint &rPoint);
std::ostream &operator <<(std::ostream& s, const CGSize &rSize);
std::ostream &operator <<(std::ostream& s, CGColorRef pSize);
std::ostream &operator <<(std::ostream& s, const CGAffineTransform &aXform);
std::ostream &operator <<(std::ostream& s, CGColorSpaceRef cs);

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
